@@ -12,7 +12,6 @@ from typing import (
 )
 
 from orjson import OPT_OMIT_MICROSECONDS, OPT_SERIALIZE_NUMPY, dumps, loads
-from starlette.datastructures import Headers
 
 from starlite.connection.base import (
     ASGIConnection,
@@ -21,6 +20,7 @@ from starlite.connection.base import (
     empty_receive,
     empty_send,
 )
+from starlite.datastructures.headers import Headers
 from starlite.exceptions import WebSocketDisconnect, WebSocketException
 from starlite.status_codes import WS_1000_NORMAL_CLOSURE
 from starlite.utils.serialization import default_serializer
@@ -137,10 +137,10 @@ class WebSocket(
             _headers: List[Tuple[bytes, bytes]] = headers if isinstance(headers, list) else []
 
             if isinstance(headers, dict):
-                _headers = Headers(headers=headers).raw
+                _headers = Headers(headers=headers).to_header_list()
 
             if isinstance(headers, Headers):
-                _headers = headers.raw
+                _headers = headers.to_header_list()
 
             event: "WebSocketAcceptEvent" = {
                 "type": "websocket.accept",
