@@ -1,7 +1,12 @@
 from starlite.datastructures.background_tasks import BackgroundTask, BackgroundTasks
 from starlite.datastructures.cookie import Cookie
 from starlite.datastructures.form_multi_dict import FormMultiDict
-from starlite.datastructures.headers import CacheControlHeader, ETag
+from starlite.datastructures.headers import (
+    CacheControlHeader,
+    ETag,
+    Headers,
+    MutableScopeHeaders,
+)
 from starlite.datastructures.provide import Provide
 from starlite.datastructures.response_containers import (
     File,
@@ -17,11 +22,13 @@ from starlite.datastructures.upload_file import UploadFile
 __all__ = (
     "BackgroundTask",
     "BackgroundTasks",
-    "Cookie",
     "CacheControlHeader",
+    "Cookie",
     "ETag",
     "File",
     "FormMultiDict",
+    "Headers",
+    "MutableScopeHeaders",
     "Provide",
     "Redirect",
     "ResponseContainer",
