@@ -51,3 +51,18 @@ class Cookie(BaseModel):
             if value is not None:
                 simple_cookie[self.key][key] = value
         return simple_cookie.output(**kwargs).strip()
+
+    def __eq__(self, other: Any) -> bool:
+        """Custom implementation to allow using equality operators on class
+        instances.
+
+        Args:
+            other: An arbitrary value
+
+        Returns:
+            Determines whether two cookie instances are equal according to the cookie spec, i.e.
+            they have a similar path, domain and key.
+        """
+        if isinstance(other, type(self)):
+            return other.key == self.key and other.path == self.path and other.domain == self.domain
+        return False
